@@ -3,8 +3,7 @@ import numpy as np
 
 
 class Sigmoid(Activation):
-    """A layer which applies the Sigmoid operation to an input.
-    """
+    """A layer which applies the Sigmoid operation to an input."""
 
     def forward(self, X: np.ndarray) -> np.ndarray:
         return 1 / (1 + np.exp(-X))
@@ -14,8 +13,7 @@ class Sigmoid(Activation):
 
 
 class Relu(Activation):
-    """A layer which applies the ReLU operation to an input.
-    """
+    """A layer which applies the ReLU operation to an input."""
 
     def forward(self, X: np.ndarray) -> np.ndarray:
         return abs(X) * (X > 0)
@@ -25,8 +23,7 @@ class Relu(Activation):
 
 
 class Softmax(Activation):
-    """A layer which applies the Softmax operation to an input.
-    """
+    """A layer which applies the Softmax operation to an input."""
 
     def forward(self, X: np.ndarray) -> np.ndarray:
         e_x = np.exp(X - np.max(X, axis=-1, keepdims=True))
